summaryrefslogtreecommitdiff
path: root/gstreamer-sharp/glib-sharp/Global.cs
diff options
context:
space:
mode:
Diffstat (limited to 'gstreamer-sharp/glib-sharp/Global.cs')
-rw-r--r--gstreamer-sharp/glib-sharp/Global.cs14
1 files changed, 7 insertions, 7 deletions
diff --git a/gstreamer-sharp/glib-sharp/Global.cs b/gstreamer-sharp/glib-sharp/Global.cs
index 80ec064..25b5adb 100644
--- a/gstreamer-sharp/glib-sharp/Global.cs
+++ b/gstreamer-sharp/glib-sharp/Global.cs
@@ -1,4 +1,4 @@
// GLib.Global.cs - Global glib properties and methods.
//
// Author: Andres G. Aragoneses <aaragoneses@novell.com>
//
@@ -33,12 +33,12 @@ namespace Gst.GLib {
public static string ProgramName {
get {
- return GLib.Marshaller.PtrToStringGFree(g_get_prgname());
+ return Gst.GLib.Marshaller.PtrToStringGFree(g_get_prgname());
}
set {
- IntPtr native_name = GLib.Marshaller.StringToPtrGStrdup (value);
+ IntPtr native_name = Gst.GLib.Marshaller.StringToPtrGStrdup (value);
g_set_prgname (native_name);
- GLib.Marshaller.Free (native_name);
+ Gst.GLib.Marshaller.Free (native_name);
}
}
@@ -50,12 +50,12 @@ namespace Gst.GLib {
public static string ApplicationName {
get {
- return GLib.Marshaller.PtrToStringGFree(g_get_application_name());
+ return Gst.GLib.Marshaller.PtrToStringGFree(g_get_application_name());
}
set {
- IntPtr native_name = GLib.Marshaller.StringToPtrGStrdup (value);
+ IntPtr native_name = Gst.GLib.Marshaller.StringToPtrGStrdup (value);
g_set_application_name (native_name);
- GLib.Marshaller.Free (native_name);
+ Gst.GLib.Marshaller.Free (native_name);
}
}
@@ -1,4 +1,4 @@
-// GLib.Global.cs - Global glib properties and methods.
+// Gst.GLib.Global.cs - Global glib properties and methods.
//
// Author: Andres G. Aragoneses <aaragoneses@novell.com>